<?php
/**
 * BP-Activity Privacy loader
 *
 * @package BP-Activity-Privacy
 */
 
// Exit if accessed directly
if ( !defined( 'ABSPATH' ) ) exit;

//check for textdomain in global wordpress langagues directory
$textdomain_global = trailingslashit( WP_LANG_DIR ) . 'buddypress-activity-privacy-' . get_locale() . '.mo';
if( file_exists( $textdomain_global ) ) 
	load_textdomain( 'bp-activity-privacy', $textdomain_global );
else{
	//textdomain loader
	$textdomain_local = BP_ACTIVITY_PRIVACY_PLUGIN_DIR . '/languages/buddypress-activity-privacy-' . get_locale() . '.mo';
	if ( file_exists( $textdomain_local ) )
		load_textdomain( 'bp-activity-privacy', $textdomain_local );
}
	
/**
 * BP_Activity_Privacy Class
 */
class BP_Activity_Privacy {

	var $profile_activity_privacy_levels = array();
	var $groups_activity_privacy_levels = array();

	var $profile_activity_visibility_levels = array();
	var $groups_activity_visibility_levels = array();

	function __construct() {
		global $bp;

		// Register the visibility levels
		$this->profile_activity_privacy_levels = array(
			'public', 'loggedin', 'adminsonly', 'onlyme'
		);

		$this->groups_activity_privacy_levels = array(
			'public', 'loggedin', 'adminsonly', 'onlyme'
		);

		if ( bp_is_active( 'friends' ) ) {
			$this->profile_activity_privacy_levels [] = 'friends';
			$this->groups_activity_privacy_levels [] = 'friends';
		}

		if ( bp_is_active( 'groups' ) ) {
			$this->groups_activity_privacy_levels [] = 'groupfriends';
			$this->groups_activity_privacy_levels [] = 'grouponly';
			$this->groups_activity_privacy_levels [] = 'groupmoderators';
			$this->groups_activity_privacy_levels [] = 'groupadmins';
		}
		
		// Register the visibility levels
		$this->profile_activity_visibility_levels  = array(
	        'public' => array(
	            'id'        => 'public',
	            'label'     => __( 'Anyone', 'bp-activity-privacy' ),
	            'default'   => true,
	            'position'  => 10
	        ),
	        'loggedin' => array(
	            'id'      => 'loggedin',
	            'label'   => __( 'Logged In Users', 'bp-activity-privacy' ),
	            'default' => false,
	            'position'  => 20
	        )
	    );

	    if ( bp_is_active( 'friends' ) ) {
	        $this->profile_activity_visibility_levels['friends'] = array(
	            'id'      => 'friends',
	            'label'   => __( 'My Friends', 'bp-activity-privacy' ),
	            'default' => false,
	            'position'  => 30
	        );
	    }

	    $this->profile_activity_visibility_levels['adminsonly'] = array(
	        'id'      => 'adminsonly',
	        'label'   => __( 'Admins Only', 'bp-activity-privacy' ),
	        'default' => false,
	        'position'  => 40
	    );

	    $this->profile_activity_visibility_levels['onlyme'] = array(
	        'id'      => 'onlyme',
	        'label'   => __( 'Only me', 'bp-activity-privacy' ),
	        'default' => false,
	        'position'  => 50
	    );

	    $this->groups_activity_visibility_levels = array(
	        'public' => array(
	            'id'      => 'public',
	            'label'   => __( 'Anyone', 'bp-activity-privacy' ),
	            'default' => true,
	            'position'  => 10
	        ),
	        'loggedin' => array(
	            'id'      => 'loggedin',
	            'label'   => __( 'Logged In Users', 'bp-activity-privacy' ),
	            'default' => false,
	             'position'  => 20
	        )
	    );

	    if ( bp_is_active( 'friends' ) ) {
	        $this->groups_activity_visibility_levels['friends'] = array(
	            'id'      => 'friends',
	            'label'   => __( 'My Friends', 'bp-activity-privacy' ),
	            'default' => false,
	            'position'  => 30
	        );
	        if ( bp_is_active( 'groups' ) ) {
		        $this->groups_activity_visibility_levels['groupfriends'] = array(
		            'id'      => 'groupfriends',
		            'label'   => __( 'My Friends in Group', 'bp-activity-privacy' ),
		            'default' => false,
		            'position'  => 40
		        );
	   		}
	    }

	    if ( bp_is_active( 'groups' ) ) {
	        $this->groups_activity_visibility_levels['grouponly'] = array(
	            'id'      => 'grouponly',
	            'label'   => __( 'Group Members', 'bp-activity-privacy' ),
	            'default' => false,
	            'position'  => 50,
	        );

	        $this->groups_activity_visibility_levels['groupmoderators'] = array(
	            'id'      => 'groupmoderators',
	            'label'   => __( 'Group Moderators', 'bp-activity-privacy' ),
	            'default' => false,
	            'position'  => 60,
	        );

	        $this->groups_activity_visibility_levels['groupadmins'] = array(
	            'id'      => 'groupadmins',
	            'label'   => __( 'Group Admins', 'bp-activity-privacy' ),
	            'default' => false,
	            'position'  => 70,
	        );
		}	  

		$this->groups_activity_visibility_levels['adminsonly'] = array(
	        'id'      => 'adminsonly',
	        'label'   => __( 'Admins Only', 'bp-activity-privacy' ),
	        'default' => false,
	        'position'  => 80,
	    );

	    $this->groups_activity_visibility_levels['onlyme'] = array(
	        'id'      => 'onlyme',
	        'label'   => __( 'Only me', 'bp-activity-privacy' ),
	        'default' => false,
	        'position'  => 90,
	    );      

		 $this->includes();
	}

	function includes() {
		// Files to include
		include( BP_ACTIVITY_PRIVACY_PLUGIN_DIR . '/includes/bp-activity-privacy-actions.php' );
		include( BP_ACTIVITY_PRIVACY_PLUGIN_DIR . '/includes/bp-activity-privacy-filters.php' );
		include( BP_ACTIVITY_PRIVACY_PLUGIN_DIR . '/includes/bp-activity-privacy-template.php' );
		include( BP_ACTIVITY_PRIVACY_PLUGIN_DIR . '/includes/bp-activity-privacy-functions.php' );
		include( BP_ACTIVITY_PRIVACY_PLUGIN_DIR . '/includes/bp-activity-privacy-cssjs.php' );
		include( BP_ACTIVITY_PRIVACY_PLUGIN_DIR . '/includes/bp-activity-privacy-ajax.php' );

		// fix / integration with some plugins
		include( BP_ACTIVITY_PRIVACY_PLUGIN_DIR . '/includes/bp-activity-privacy-integrations.php' );

		// As an follow of how you might do it manually, let's include the functions used
		// on the WordPress Dashboard conditionally:	
		if ( is_admin() || is_network_admin() ) {
			include( BP_ACTIVITY_PRIVACY_PLUGIN_DIR . '/includes/bp-activity-privacy-admin.php' );
		}
		
	}
}

function bp_activity_privacy_load_core() {
	global $bp, $bp_activity_privacy;

	$bp_activity_privacy = new BP_Activity_Privacy;
	do_action('bp_activity_privacy_load_core');
}
add_action( 'bp_loaded', 'bp_activity_privacy_load_core', 5 );